@@ -1,7 +1,9 @@
 package Acme::CPANModules::PortedFrom::Ruby;
 
-our $DATE = '2018-12-22'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-10-16'; # DATE
+our $DIST = 'Acme-CPANModules-PortedFrom-Ruby'; # DIST
+our $VERSION = '0.002'; # VERSION
 
 our $LIST = {
     summary => "Modules/applications that are ported from (or inspired by) ".
@@ -17,6 +19,11 @@ _
             #ruby_package => undef',
             tags => ['web'],
         },
+        {
+            module => 'Scientist',
+            #ruby_package => undef',
+            #tags => [''],
+        },
     ],
 };
 
@@ -35,22 +42,39 @@ Acme::CPANModules::PortedFrom::Ruby - Modules/applications that are ported from
 
 =head1 VERSION
 
-This document describes version 0.001 of Acme::CPANModules::PortedFrom::Ruby (from Perl distribution Acme-CPANModules-PortedFrom-Ruby), released on 2018-12-22.
+This document describes version 0.002 of Acme::CPANModules::PortedFrom::Ruby (from Perl distribution Acme-CPANModules-PortedFrom-Ruby), released on 2020-10-16.
 
 =head1 DESCRIPTION
 
-Modules/applications that are ported from (or inspired by) Ruby libraries.
-
 If you know of others, please drop me a message.
 
-=head1 INCLUDED MODULES
+=head1 MODULES INCLUDED IN THIS ACME::CPANMODULE MODULE
 
 =over
 
 =item * L<App::Sass>
 
+=item * L<Scientist>
+
 =back
 
+=head1 FAQ
+
+=head2 What are ways to use this module?
+
+Aside from reading it, you can install all the listed modules using
+L<cpanmodules>:
+
+    % cpanmodules ls-entries PortedFrom::Ruby | cpanm -n
+
+or L<Acme::CM::Get>:
+
+    % perl -MAcme::CM::Get=PortedFrom::Ruby -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n
+
+This module also helps L<lcpan> produce a more meaningful result for C<lcpan
+related-mods> when it comes to finding related modules for the modules listed
+in this Acme::CPANModules module.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModules-PortedFrom-Ruby>.
@@ -79,7 +103,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
